/**
 * Fuzed the game!
 * Classic platformer meets pervasive gaming
 */
var Fuzed = {
  world: [640, 384], // World size
  Player: null, // Placeholder
  /**
   * Shake entire viewport
   * 
   * @param {Integer} time
   * @return void
   */
  shake: (function() {
    var step = 10,
        mod = 1,
        interval,
        timeout;
      
    return function(time) {
      interval = setInterval(function() {
        var move = mod*step;
        Crafty.viewport.x -= move;
        Crafty.viewport.y += move;
        mod *= -1;
      }, 200);
      
      timeout && clearTimeout(timeout);
      timeout = setTimeout(function() {
        clearInterval(interval);
      }, time || 2000);
    }
  })(),
  /**
   * Makes snow for stage
   * 
   * @param {Boolean} status
   */
  snow: function(status) {
    if (status) {
      $('.snow').css("opacity", 1);
      $('.snow').removeClass("snow-hide");
    }
    else {
      $('.snow').css("opacity", 0);
    }
  },
  /**
   * Toggle snow for stage. Uses Fuzed.snow
   */
  toggleSnow: (function() {
    var status = true;
    
    return function() {
      Fuzed.snow(status);
      status = status ? false : true;
    };
  })(),
  /**
   * Pauses game
   */
  pause: (function() {
    var isPaused = false;

    return function() {
      $("#pause")[isPaused ? "hide" : "show"]();
      $("#about").hide();
      isPaused = !isPaused;
      Crafty.pause();
    };
  })(),
  /**
   * Tracks temperature and updates gameplay.
   *
   * @param {Integer|Boolean} low - if false then stop tracking else represents low temp
   * @param {Integer} medium - represents medium temp
   * @param {Integer} high - represents high temp
   */
  trackTemperature: (function() {
    var track = false,
        trackInterval,
        _low = 22,
        _medium = 23,
        _high = 26;

    return function(low, medium, hight) {
      // Stop tracking
      if (_low === false) {
        clearInterval(trackInterval);
      }
      _low = low || _low;
      _medium = medium || _medium;
      _high = hight || _high;
      if (!window.plugins.arduino) {
        return null;
      }
      var img = $("#temp .img");
      trackInterval = setInterval(function() {
        window.plugins.arduino.getTemperature(
          function(response) {
            var val = +response.value;
            $("#temp .value").html(val+'<span style="font-size: 14px;">&#8451;</span>');

            if (val <= _low) {
              img.css("background-image", "url(gfx/temp_low.png)");
              Fuzed.snow(true);
            }
            else {
              if (val <= medium) {
                img.css("background-image", "url(gfx/temp_med.png)");
              }
              else {
                img.css("background-image", "url(gfx/temp_high.png)");
              }
              Fuzed.snow(false);
            }
          },
          function(response) {
            alert("Error reciving data from Arduino.");
          }
        );
      }, 2000);
    };
  })()
};